use std::borrow::Cow;

#[derive(PartialEq, Debug)]
pub enum Status {
    Main,
    RegisterItem(RegisterItemStatus),
    RentItem(RentItemStatus),
    ReturnItem(ReturnItemStatus),
}

impl Status {
    pub fn prompt(&self) -> Cow<'static, str> {
        match self {
            Status::Main => "command".into(),
            Status::RegisterItem(r) => r.prompt(),
            Status::RentItem(r) => r.prompt(),
            Status::ReturnItem(r) => r.prompt(),
        }
    }
}

#[derive(PartialEq, Debug)]
pub enum RegisterItemStatus {
    InsertItemId,
    InsertItemName { id: String },
}

impl RegisterItemStatus {
    pub fn prompt(&self) -> Cow<'static, str> {
        match self {
            RegisterItemStatus::InsertItemId => "register-item:id".into(),
            RegisterItemStatus::InsertItemName { .. } => {
                "register-item:name".into()
            }
        }
    }
}

#[derive(PartialEq, Debug)]
pub enum RentItemStatus {
    InsertRenter,
    InsertItemId { renter: String },
}

impl RentItemStatus {
    pub fn prompt(&self) -> Cow<'static, str> {
        match self {
            RentItemStatus::InsertRenter => "rent-item:renter".into(),
            RentItemStatus::InsertItemId { .. } => "rent-item:id".into(),
        }
    }
}

#[derive(PartialEq, Debug)]
pub enum ReturnItemStatus {
    InsertItemId,
}

impl ReturnItemStatus {
    pub fn prompt(&self) -> Cow<'static, str> {
        match self {
            ReturnItemStatus::InsertItemId => "return-item:id".into(),
        }
    }
}
